@@ -10,7 +10,7 @@ import cgi
 from cStringIO import StringIO
 from urllib import urlencode
 from urllib2 import urlopen
-from owslib.util import openURL, testXMLValue, extract_xml_list, ServiceException
+from owslib.util import openURL, testXMLValue, extract_xml_list, ServiceException, xmltag_split
 from owslib.etree import etree
 from owslib.fgdc import Metadata
 from owslib.iso import MD_Metadata
@@ -49,7 +49,7 @@ class WebFeatureService_1_0_0(object):
 
     Implements IWebFeatureService.
     """
-    def __new__(self,url, version, xml, parse_remote_metadata=False):
+    def __new__(self,url, version, xml, parse_remote_metadata=False, timeout=30):
         """ overridden __new__ method 
         
         @type url: string
@@ -58,10 +58,11 @@ class WebFeatureService_1_0_0(object):
         @param xml: elementtree object
         @type parse_remote_metadata: boolean
         @param parse_remote_metadata: whether to fully process MetadataURL elements
+        @param timeout: time (in seconds) after which requests should timeout
         @return: initialized WebFeatureService_1_0_0 object
         """
         obj=object.__new__(self)
-        obj.__init__(url, version, xml, parse_remote_metadata)
+        obj.__init__(url, version, xml, parse_remote_metadata, timeout)
         return obj
     
     def __getitem__(self,name):
@@ -72,10 +73,11 @@ class WebFeatureService_1_0_0(object):
             raise KeyError, "No content named %s" % name
     
     
-    def __init__(self, url, version, xml=None, parse_remote_metadata=False):
+    def __init__(self, url, version, xml=None, parse_remote_metadata=False, timeout=30):
         """Initialize."""
         self.url = url
         self.version = version
+        self.timeout = timeout
         self._capabilities = None
         reader = WFSCapabilitiesReader(self.version)
         if xml:
@@ -113,12 +115,12 @@ class WebFeatureService_1_0_0(object):
         self.exceptions = [f.text for f \
                 in self._capabilities.findall('Capability/Exception/Format')]
       
-    def getcapabilities(self, timeout=30):
+    def getcapabilities(self):
         """Request and return capabilities document from the WFS as a 
         file-like object.
         NOTE: this is effectively redundant now"""
         reader = WFSCapabilitiesReader(self.version)
-        return urlopen(reader.capabilities_url(self.url), timeout=timeout)
+        return urlopen(reader.capabilities_url(self.url), timeout=self.timeout)
     
     def items(self):
         '''supports dict-like items() access'''
@@ -129,7 +131,8 @@ class WebFeatureService_1_0_0(object):
     
     def getfeature(self, typename=None, filter=None, bbox=None, featureid=None,
                    featureversion=None, propertyname=['*'], maxfeatures=None,
-                   srsname=None, outputFormat=None, method='{http://www.opengis.net/wfs}Get'):
+                   srsname=None, outputFormat=None, method='{http://www.opengis.net/wfs}Get',
+                   startindex=None):
         """Request and return feature data as a file-like object.
         
         Parameters
@@ -154,6 +157,8 @@ class WebFeatureService_1_0_0(object):
             EPSG code to request the data in
         outputFormat: string (optional)
             Requested response format of the request.
+        startindex: int (optional)
+            Start position to return feature set (paging in combination with maxfeatures)
 
             
         There are 3 different modes of use
@@ -162,9 +167,11 @@ class WebFeatureService_1_0_0(object):
         2) typename and filter (more expressive)
         3) featureid (direct access to known features)
         """
-        base_url = self.getOperationByName('{http://www.opengis.net/wfs}GetFeature').methods[method]['url']
+        try:
+            base_url = next((m.get('url') for m in self.getOperationByName('GetFeature').methods if m.get('type').lower() == method.lower()))
+        except StopIteration:
+            base_url = self.url
         request = {'service': 'WFS', 'version': self.version, 'request': 'GetFeature'}
-        
 
         # check featureid
         if featureid:
@@ -184,13 +191,14 @@ class WebFeatureService_1_0_0(object):
             request['propertyname'] = ','.join(propertyname)
         if featureversion: request['featureversion'] = str(featureversion)
         if maxfeatures: request['maxfeatures'] = str(maxfeatures)
+        if startindex: request['startindex'] = str(startindex)
 
         if outputFormat is not None:
             request["outputFormat"] = outputFormat
 
         data = urlencode(request)
         log.debug("Making request: %s?%s" % (base_url, data))
-        u = openURL(base_url, data, method)
+        u = openURL(base_url, data, method, timeout=self.timeout)
         
         
         # check for service exceptions, rewrap, and return
@@ -318,6 +326,7 @@ class ContentMetadata:
 
             self.metadataUrls.append(metadataUrl)
 
+
 class OperationMetadata:
     """Abstraction for WFS metadata.
     
@@ -325,14 +334,13 @@ class OperationMetadata:
     """
     def __init__(self, elem):
         """."""
-        self.name = elem.tag
+        self.name = xmltag_split(elem.tag)
         # formatOptions
         self.formatOptions = [f.tag for f in elem.findall(nspath('ResultFormat/*'))]
-        methods = []
+        self.methods = []
         for verb in elem.findall(nspath('DCPType/HTTP/*')):
             url = verb.attrib['onlineResource']
-            methods.append((verb.tag, {'url': url}))
-        self.methods = dict(methods)
+            self.methods.append({'type' : xmltag_split(verb.tag), 'url': url})
 
 
 class WFSCapabilitiesReader(object):
